from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.StepData import *
from OCC.Core.Interface import *
from OCC.Core.StepFEA import *


class RWStepFEA_RWAlignedCurve3dElementCoordinateSystem:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepFEA_AlignedCurve3dElementCoordinateSystem) -> None: ...
	def Share(self, ent: StepFEA_AlignedCurve3dElementCoordinateSystem, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepFEA_AlignedCurve3dElementCoordinateSystem) -> None: ...

class RWStepFEA_RWAlignedSurface3dElementCoordinateSystem:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepFEA_AlignedSurface3dElementCoordinateSystem) -> None: ...
	def Share(self, ent: StepFEA_AlignedSurface3dElementCoordinateSystem, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepFEA_AlignedSurface3dElementCoordinateSystem) -> None: ...

class RWStepFEA_RWArbitraryVolume3dElementCoordinateSystem:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepFEA_ArbitraryVolume3dElementCoordinateSystem) -> None: ...
	def Share(self, ent: StepFEA_ArbitraryVolume3dElementCoordinateSystem, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepFEA_ArbitraryVolume3dElementCoordinateSystem) -> None: ...

class RWStepFEA_RWConstantSurface3dElementCoordinateSystem:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepFEA_ConstantSurface3dElementCoordinateSystem) -> None: ...
	def Share(self, ent: StepFEA_ConstantSurface3dElementCoordinateSystem, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepFEA_ConstantSurface3dElementCoordinateSystem) -> None: ...

class RWStepFEA_RWCurve3dElementProperty:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepFEA_Curve3dElementProperty) -> None: ...
	def Share(self, ent: StepFEA_Curve3dElementProperty, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepFEA_Curve3dElementProperty) -> None: ...

class RWStepFEA_RWCurve3dElementRepresentation:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepFEA_Curve3dElementRepresentation) -> None: ...
	def Share(self, ent: StepFEA_Curve3dElementRepresentation, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepFEA_Curve3dElementRepresentation) -> None: ...

class RWStepFEA_RWCurveElementEndOffset:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepFEA_CurveElementEndOffset) -> None: ...
	def Share(self, ent: StepFEA_CurveElementEndOffset, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepFEA_CurveElementEndOffset) -> None: ...

class RWStepFEA_RWCurveElementEndRelease:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepFEA_CurveElementEndRelease) -> None: ...
	def Share(self, ent: StepFEA_CurveElementEndRelease, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepFEA_CurveElementEndRelease) -> None: ...

class RWStepFEA_RWCurveElementInterval:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepFEA_CurveElementInterval) -> None: ...
	def Share(self, ent: StepFEA_CurveElementInterval, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepFEA_CurveElementInterval) -> None: ...

class RWStepFEA_RWCurveElementIntervalConstant:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepFEA_CurveElementIntervalConstant) -> None: ...
	def Share(self, ent: StepFEA_CurveElementIntervalConstant, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepFEA_CurveElementIntervalConstant) -> None: ...

class RWStepFEA_RWCurveElementIntervalLinearlyVarying:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepFEA_CurveElementIntervalLinearlyVarying) -> None: ...
	def Share(self, ent: StepFEA_CurveElementIntervalLinearlyVarying, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepFEA_CurveElementIntervalLinearlyVarying) -> None: ...

class RWStepFEA_RWCurveElementLocation:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepFEA_CurveElementLocation) -> None: ...
	def Share(self, ent: StepFEA_CurveElementLocation, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepFEA_CurveElementLocation) -> None: ...

class RWStepFEA_RWDummyNode:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepFEA_DummyNode) -> None: ...
	def Share(self, ent: StepFEA_DummyNode, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepFEA_DummyNode) -> None: ...

class RWStepFEA_RWElementGeometricRelationship:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepFEA_ElementGeometricRelationship) -> None: ...
	def Share(self, ent: StepFEA_ElementGeometricRelationship, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepFEA_ElementGeometricRelationship) -> None: ...

class RWStepFEA_RWElementGroup:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepFEA_ElementGroup) -> None: ...
	def Share(self, ent: StepFEA_ElementGroup, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepFEA_ElementGroup) -> None: ...

class RWStepFEA_RWElementRepresentation:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepFEA_ElementRepresentation) -> None: ...
	def Share(self, ent: StepFEA_ElementRepresentation, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepFEA_ElementRepresentation) -> None: ...

class RWStepFEA_RWFeaAreaDensity:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepFEA_FeaAreaDensity) -> None: ...
	def Share(self, ent: StepFEA_FeaAreaDensity, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepFEA_FeaAreaDensity) -> None: ...

class RWStepFEA_RWFeaAxis2Placement3d:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepFEA_FeaAxis2Placement3d) -> None: ...
	def Share(self, ent: StepFEA_FeaAxis2Placement3d, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepFEA_FeaAxis2Placement3d) -> None: ...

class RWStepFEA_RWFeaCurveSectionGeometricRelationship:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepFEA_FeaCurveSectionGeometricRelationship) -> None: ...
	def Share(self, ent: StepFEA_FeaCurveSectionGeometricRelationship, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepFEA_FeaCurveSectionGeometricRelationship) -> None: ...

class RWStepFEA_RWFeaGroup:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepFEA_FeaGroup) -> None: ...
	def Share(self, ent: StepFEA_FeaGroup, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepFEA_FeaGroup) -> None: ...

class RWStepFEA_RWFeaLinearElasticity:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepFEA_FeaLinearElasticity) -> None: ...
	def Share(self, ent: StepFEA_FeaLinearElasticity, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepFEA_FeaLinearElasticity) -> None: ...

class RWStepFEA_RWFeaMassDensity:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepFEA_FeaMassDensity) -> None: ...
	def Share(self, ent: StepFEA_FeaMassDensity, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepFEA_FeaMassDensity) -> None: ...

class RWStepFEA_RWFeaMaterialPropertyRepresentation:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepFEA_FeaMaterialPropertyRepresentation) -> None: ...
	def Share(self, ent: StepFEA_FeaMaterialPropertyRepresentation, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepFEA_FeaMaterialPropertyRepresentation) -> None: ...

class RWStepFEA_RWFeaMaterialPropertyRepresentationItem:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepFEA_FeaMaterialPropertyRepresentationItem) -> None: ...
	def Share(self, ent: StepFEA_FeaMaterialPropertyRepresentationItem, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepFEA_FeaMaterialPropertyRepresentationItem) -> None: ...

class RWStepFEA_RWFeaModel:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepFEA_FeaModel) -> None: ...
	def Share(self, ent: StepFEA_FeaModel, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepFEA_FeaModel) -> None: ...

class RWStepFEA_RWFeaModel3d:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepFEA_FeaModel3d) -> None: ...
	def Share(self, ent: StepFEA_FeaModel3d, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepFEA_FeaModel3d) -> None: ...

class RWStepFEA_RWFeaModelDefinition:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepFEA_FeaModelDefinition) -> None: ...
	def Share(self, ent: StepFEA_FeaModelDefinition, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepFEA_FeaModelDefinition) -> None: ...

class RWStepFEA_RWFeaMoistureAbsorption:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepFEA_FeaMoistureAbsorption) -> None: ...
	def Share(self, ent: StepFEA_FeaMoistureAbsorption, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepFEA_FeaMoistureAbsorption) -> None: ...

class RWStepFEA_RWFeaParametricPoint:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepFEA_FeaParametricPoint) -> None: ...
	def Share(self, ent: StepFEA_FeaParametricPoint, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepFEA_FeaParametricPoint) -> None: ...

class RWStepFEA_RWFeaRepresentationItem:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepFEA_FeaRepresentationItem) -> None: ...
	def Share(self, ent: StepFEA_FeaRepresentationItem, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepFEA_FeaRepresentationItem) -> None: ...

class RWStepFEA_RWFeaSecantCoefficientOfLinearThermalExpansion:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepFEA_FeaSecantCoefficientOfLinearThermalExpansion) -> None: ...
	def Share(self, ent: StepFEA_FeaSecantCoefficientOfLinearThermalExpansion, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepFEA_FeaSecantCoefficientOfLinearThermalExpansion) -> None: ...

class RWStepFEA_RWFeaShellBendingStiffness:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepFEA_FeaShellBendingStiffness) -> None: ...
	def Share(self, ent: StepFEA_FeaShellBendingStiffness, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepFEA_FeaShellBendingStiffness) -> None: ...

class RWStepFEA_RWFeaShellMembraneBendingCouplingStiffness:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepFEA_FeaShellMembraneBendingCouplingStiffness) -> None: ...
	def Share(self, ent: StepFEA_FeaShellMembraneBendingCouplingStiffness, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepFEA_FeaShellMembraneBendingCouplingStiffness) -> None: ...

class RWStepFEA_RWFeaShellMembraneStiffness:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepFEA_FeaShellMembraneStiffness) -> None: ...
	def Share(self, ent: StepFEA_FeaShellMembraneStiffness, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepFEA_FeaShellMembraneStiffness) -> None: ...

class RWStepFEA_RWFeaShellShearStiffness:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepFEA_FeaShellShearStiffness) -> None: ...
	def Share(self, ent: StepFEA_FeaShellShearStiffness, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepFEA_FeaShellShearStiffness) -> None: ...

class RWStepFEA_RWFeaSurfaceSectionGeometricRelationship:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepFEA_FeaSurfaceSectionGeometricRelationship) -> None: ...
	def Share(self, ent: StepFEA_FeaSurfaceSectionGeometricRelationship, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepFEA_FeaSurfaceSectionGeometricRelationship) -> None: ...

class RWStepFEA_RWFeaTangentialCoefficientOfLinearThermalExpansion:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepFEA_FeaTangentialCoefficientOfLinearThermalExpansion) -> None: ...
	def Share(self, ent: StepFEA_FeaTangentialCoefficientOfLinearThermalExpansion, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepFEA_FeaTangentialCoefficientOfLinearThermalExpansion) -> None: ...

class RWStepFEA_RWFreedomAndCoefficient:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepFEA_FreedomAndCoefficient) -> None: ...
	def Share(self, ent: StepFEA_FreedomAndCoefficient, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepFEA_FreedomAndCoefficient) -> None: ...

class RWStepFEA_RWFreedomsList:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepFEA_FreedomsList) -> None: ...
	def Share(self, ent: StepFEA_FreedomsList, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepFEA_FreedomsList) -> None: ...

class RWStepFEA_RWGeometricNode:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepFEA_GeometricNode) -> None: ...
	def Share(self, ent: StepFEA_GeometricNode, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepFEA_GeometricNode) -> None: ...

class RWStepFEA_RWNode:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepFEA_Node) -> None: ...
	def Share(self, ent: StepFEA_Node, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepFEA_Node) -> None: ...

class RWStepFEA_RWNodeDefinition:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepFEA_NodeDefinition) -> None: ...
	def Share(self, ent: StepFEA_NodeDefinition, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepFEA_NodeDefinition) -> None: ...

class RWStepFEA_RWNodeGroup:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepFEA_NodeGroup) -> None: ...
	def Share(self, ent: StepFEA_NodeGroup, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepFEA_NodeGroup) -> None: ...

class RWStepFEA_RWNodeRepresentation:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepFEA_NodeRepresentation) -> None: ...
	def Share(self, ent: StepFEA_NodeRepresentation, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepFEA_NodeRepresentation) -> None: ...

class RWStepFEA_RWNodeSet:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepFEA_NodeSet) -> None: ...
	def Share(self, ent: StepFEA_NodeSet, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepFEA_NodeSet) -> None: ...

class RWStepFEA_RWNodeWithSolutionCoordinateSystem:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepFEA_NodeWithSolutionCoordinateSystem) -> None: ...
	def Share(self, ent: StepFEA_NodeWithSolutionCoordinateSystem, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepFEA_NodeWithSolutionCoordinateSystem) -> None: ...

class RWStepFEA_RWNodeWithVector:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepFEA_NodeWithVector) -> None: ...
	def Share(self, ent: StepFEA_NodeWithVector, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepFEA_NodeWithVector) -> None: ...

class RWStepFEA_RWParametricCurve3dElementCoordinateDirection:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepFEA_ParametricCurve3dElementCoordinateDirection) -> None: ...
	def Share(self, ent: StepFEA_ParametricCurve3dElementCoordinateDirection, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepFEA_ParametricCurve3dElementCoordinateDirection) -> None: ...

class RWStepFEA_RWParametricCurve3dElementCoordinateSystem:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepFEA_ParametricCurve3dElementCoordinateSystem) -> None: ...
	def Share(self, ent: StepFEA_ParametricCurve3dElementCoordinateSystem, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepFEA_ParametricCurve3dElementCoordinateSystem) -> None: ...

class RWStepFEA_RWParametricSurface3dElementCoordinateSystem:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepFEA_ParametricSurface3dElementCoordinateSystem) -> None: ...
	def Share(self, ent: StepFEA_ParametricSurface3dElementCoordinateSystem, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepFEA_ParametricSurface3dElementCoordinateSystem) -> None: ...

class RWStepFEA_RWSurface3dElementRepresentation:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepFEA_Surface3dElementRepresentation) -> None: ...
	def Share(self, ent: StepFEA_Surface3dElementRepresentation, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepFEA_Surface3dElementRepresentation) -> None: ...

class RWStepFEA_RWVolume3dElementRepresentation:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepFEA_Volume3dElementRepresentation) -> None: ...
	def Share(self, ent: StepFEA_Volume3dElementRepresentation, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepFEA_Volume3dElementRepresentation) -> None: ...

# harray1 classes
# harray2 classes
# hsequence classes




# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
VrmlAPI module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_vrmlapi.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _VrmlAPI
else:
    import _VrmlAPI

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _VrmlAPI.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _VrmlAPI.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _VrmlAPI.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _VrmlAPI.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _VrmlAPI.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _VrmlAPI.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _VrmlAPI.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _VrmlAPI.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _VrmlAPI.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _VrmlAPI.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _VrmlAPI.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _VrmlAPI.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _VrmlAPI.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _VrmlAPI.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _VrmlAPI.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _VrmlAPI.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _VrmlAPI.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _VrmlAPI:
_VrmlAPI.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _VrmlAPI.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.TopoDS
import OCC.Core.Message
import OCC.Core.TCollection
import OCC.Core.OSD
import OCC.Core.TColStd
import OCC.Core.TopAbs
import OCC.Core.TopLoc
import OCC.Core.gp
import OCC.Core.VrmlConverter
import OCC.Core.Adaptor3d
import OCC.Core.Geom
import OCC.Core.GeomAbs
import OCC.Core.TColgp
import OCC.Core.Adaptor2d
import OCC.Core.Geom2d
import OCC.Core.math
import OCC.Core.Aspect
import OCC.Core.Quantity
import OCC.Core.Image
import OCC.Core.Graphic3d
import OCC.Core.BVH
import OCC.Core.Bnd
import OCC.Core.Media
import OCC.Core.Vrml
import OCC.Core.TopTools
import OCC.Core.HLRAlgo
import OCC.Core.Poly
import OCC.Core.TShort
import OCC.Core.BRepAdaptor
import OCC.Core.GeomAdaptor
import OCC.Core.Geom2dAdaptor
import OCC.Core.TDocStd
import OCC.Core.TDF
import OCC.Core.CDF
import OCC.Core.CDM
import OCC.Core.Resource
import OCC.Core.PCDM
import OCC.Core.Storage

from enum import IntEnum
from OCC.Core.Exception import *

VrmlAPI_ShadedRepresentation = _VrmlAPI.VrmlAPI_ShadedRepresentation
VrmlAPI_WireFrameRepresentation = _VrmlAPI.VrmlAPI_WireFrameRepresentation
VrmlAPI_BothRepresentation = _VrmlAPI.VrmlAPI_BothRepresentation


class VrmlAPI_RepresentationOfShape(IntEnum):
	VrmlAPI_ShadedRepresentation = 0
	VrmlAPI_WireFrameRepresentation = 1
	VrmlAPI_BothRepresentation = 2
VrmlAPI_ShadedRepresentation = VrmlAPI_RepresentationOfShape.VrmlAPI_ShadedRepresentation
VrmlAPI_WireFrameRepresentation = VrmlAPI_RepresentationOfShape.VrmlAPI_WireFrameRepresentation
VrmlAPI_BothRepresentation = VrmlAPI_RepresentationOfShape.VrmlAPI_BothRepresentation

class vrmlapi(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    @staticmethod
    def Write(*args) -> "Standard_Boolean":
        r"""
        With help of this class user can change parameters of writing. converts the shape ashape to vrml format of the passed version and writes it to the file identified by afilename using default parameters.

        Parameters
        ----------
        aShape: TopoDS_Shape
        aFileName: char *
        aVersion: int,optional
        	default value is 2

        Returns
        -------
        bool

        """
        return _VrmlAPI.vrmlapi_Write(*args)

    __repr__ = _dumps_object


    def __init__(self):
        _VrmlAPI.vrmlapi_swiginit(self, _VrmlAPI.new_vrmlapi())
    __swig_destroy__ = _VrmlAPI.delete_vrmlapi

# Register vrmlapi in _VrmlAPI:
_VrmlAPI.vrmlapi_swigregister(vrmlapi)

def vrmlapi_Write(*args) -> "Standard_Boolean":
    r"""
    With help of this class user can change parameters of writing. converts the shape ashape to vrml format of the passed version and writes it to the file identified by afilename using default parameters.

    Parameters
    ----------
    aShape: TopoDS_Shape
    aFileName: char *
    aVersion: int,optional
    	default value is 2

    Returns
    -------
    bool

    """
    return _VrmlAPI.vrmlapi_Write(*args)

class VrmlAPI_Writer(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Creates a writer object with default parameters.

        Returns
        -------
        None

        """
        _VrmlAPI.VrmlAPI_Writer_swiginit(self, _VrmlAPI.new_VrmlAPI_Writer(*args))

    def Drawer(self, *args) -> "opencascade::handle< VrmlConverter_Drawer >":
        r"""
        Returns drawer object.

        Returns
        -------
        opencascade::handle<VrmlConverter_Drawer>

        """
        return _VrmlAPI.VrmlAPI_Writer_Drawer(self, *args)

    def GetFreeBoundsMaterial(self, *args) -> "opencascade::handle< Vrml_Material >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<Vrml_Material>

        """
        return _VrmlAPI.VrmlAPI_Writer_GetFreeBoundsMaterial(self, *args)

    def GetFrontMaterial(self, *args) -> "opencascade::handle< Vrml_Material >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<Vrml_Material>

        """
        return _VrmlAPI.VrmlAPI_Writer_GetFrontMaterial(self, *args)

    def GetLineMaterial(self, *args) -> "opencascade::handle< Vrml_Material >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<Vrml_Material>

        """
        return _VrmlAPI.VrmlAPI_Writer_GetLineMaterial(self, *args)

    def GetPointsMaterial(self, *args) -> "opencascade::handle< Vrml_Material >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<Vrml_Material>

        """
        return _VrmlAPI.VrmlAPI_Writer_GetPointsMaterial(self, *args)

    def GetRepresentation(self, *args) -> "VrmlAPI_RepresentationOfShape":
        r"""
        Returns the representation of the shape which is written to the vrml file. types of representation are set through the vrmlapi_representationofshape enumeration.

        Returns
        -------
        VrmlAPI_RepresentationOfShape

        """
        return _VrmlAPI.VrmlAPI_Writer_GetRepresentation(self, *args)

    def GetUisoMaterial(self, *args) -> "opencascade::handle< Vrml_Material >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<Vrml_Material>

        """
        return _VrmlAPI.VrmlAPI_Writer_GetUisoMaterial(self, *args)

    def GetUnfreeBoundsMaterial(self, *args) -> "opencascade::handle< Vrml_Material >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<Vrml_Material>

        """
        return _VrmlAPI.VrmlAPI_Writer_GetUnfreeBoundsMaterial(self, *args)

    def GetVisoMaterial(self, *args) -> "opencascade::handle< Vrml_Material >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<Vrml_Material>

        """
        return _VrmlAPI.VrmlAPI_Writer_GetVisoMaterial(self, *args)

    def GetWireMaterial(self, *args) -> "opencascade::handle< Vrml_Material >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<Vrml_Material>

        """
        return _VrmlAPI.VrmlAPI_Writer_GetWireMaterial(self, *args)

    def ResetToDefaults(self, *args) -> "void":
        r"""
        Resets all parameters (representation, deflection) to their default values..

        Returns
        -------
        None

        """
        return _VrmlAPI.VrmlAPI_Writer_ResetToDefaults(self, *args)

    def SetAmbientColorToMaterial(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aMaterial: Vrml_Material
        Color: Quantity_HArray1OfColor

        Returns
        -------
        None

        """
        return _VrmlAPI.VrmlAPI_Writer_SetAmbientColorToMaterial(self, *args)

    def SetDeflection(self, *args) -> "void":
        r"""
        Sets the deflection adef of the mesh algorithm which is used to compute the shaded representation of the translated shape. the default value is -1. when the deflection value is less than 0, the deflection is calculated from the relative size of the shaped.

        Parameters
        ----------
        aDef: float

        Returns
        -------
        None

        """
        return _VrmlAPI.VrmlAPI_Writer_SetDeflection(self, *args)

    def SetDiffuseColorToMaterial(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aMaterial: Vrml_Material
        Color: Quantity_HArray1OfColor

        Returns
        -------
        None

        """
        return _VrmlAPI.VrmlAPI_Writer_SetDiffuseColorToMaterial(self, *args)

    def SetEmissiveColorToMaterial(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aMaterial: Vrml_Material
        Color: Quantity_HArray1OfColor

        Returns
        -------
        None

        """
        return _VrmlAPI.VrmlAPI_Writer_SetEmissiveColorToMaterial(self, *args)

    def SetRepresentation(self, *args) -> "void":
        r"""
        Sets the representation of the shape arep which is written to the vrml file. the three options are : - shaded - wireframe - both shaded and wireframe (default) defined through the vrmlapi_representationofshape enumeration.

        Parameters
        ----------
        aRep: VrmlAPI_RepresentationOfShape

        Returns
        -------
        None

        """
        return _VrmlAPI.VrmlAPI_Writer_SetRepresentation(self, *args)

    def SetShininessToMaterial(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aMaterial: Vrml_Material
        aShininess: float

        Returns
        -------
        None

        """
        return _VrmlAPI.VrmlAPI_Writer_SetShininessToMaterial(self, *args)

    def SetSpecularColorToMaterial(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aMaterial: Vrml_Material
        Color: Quantity_HArray1OfColor

        Returns
        -------
        None

        """
        return _VrmlAPI.VrmlAPI_Writer_SetSpecularColorToMaterial(self, *args)

    def SetTransparencyToMaterial(self, *args) -> "void":
        r"""
        Set transparency to given material.

        Parameters
        ----------
        aMaterial: Vrml_Material
        aTransparency: float

        Returns
        -------
        None

        """
        return _VrmlAPI.VrmlAPI_Writer_SetTransparencyToMaterial(self, *args)

    def Write(self, *args) -> "Standard_Boolean":
        r"""
        Converts the shape ashape to vrml format of the passed version and writes it to the file identified by afile.

        Parameters
        ----------
        aShape: TopoDS_Shape
        aFile: char *
        aVersion: int,optional
        	default value is 2

        Returns
        -------
        bool

        """
        return _VrmlAPI.VrmlAPI_Writer_Write(self, *args)

    def WriteDoc(self, *args) -> "Standard_Boolean":
        r"""
        Converts the document to vrml format of the passed version and writes it to the file identified by afile.

        Parameters
        ----------
        theDoc: TDocStd_Document
        theFile: char *
        theScale: float

        Returns
        -------
        bool

        """
        return _VrmlAPI.VrmlAPI_Writer_WriteDoc(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _VrmlAPI.delete_VrmlAPI_Writer

# Register VrmlAPI_Writer in _VrmlAPI:
_VrmlAPI.VrmlAPI_Writer_swigregister(VrmlAPI_Writer)








# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
XmlMDataXtd module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_xmlmdataxtd.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _XmlMDataXtd
else:
    import _XmlMDataXtd

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _XmlMDataXtd.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _XmlMDataXtd.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _XmlMDataXtd.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _XmlMDataXtd.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _XmlMDataXtd.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _XmlMDataXtd.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _XmlMDataXtd.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _XmlMDataXtd.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _XmlMDataXtd.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _XmlMDataXtd.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _XmlMDataXtd.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _XmlMDataXtd.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _XmlMDataXtd.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _XmlMDataXtd.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _XmlMDataXtd.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _XmlMDataXtd.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _XmlMDataXtd.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _XmlMDataXtd:
_XmlMDataXtd.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _XmlMDataXtd.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.XmlMDF
import OCC.Core.Message
import OCC.Core.TCollection
import OCC.Core.OSD
import OCC.Core.TColStd
import OCC.Core.TDF
import OCC.Core.XmlObjMgt
import OCC.Core.LDOM
import OCC.Core.gp
import OCC.Core.Storage

from enum import IntEnum
from OCC.Core.Exception import *




def Handle_XmlMDataXtd_ConstraintDriver_Create() -> "opencascade::handle< XmlMDataXtd_ConstraintDriver >":
    return _XmlMDataXtd.Handle_XmlMDataXtd_ConstraintDriver_Create()

def Handle_XmlMDataXtd_ConstraintDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< XmlMDataXtd_ConstraintDriver >":
    return _XmlMDataXtd.Handle_XmlMDataXtd_ConstraintDriver_DownCast(t)

def Handle_XmlMDataXtd_ConstraintDriver_IsNull(t: "opencascade::handle< XmlMDataXtd_ConstraintDriver > const &") -> "bool":
    return _XmlMDataXtd.Handle_XmlMDataXtd_ConstraintDriver_IsNull(t)

def Handle_XmlMDataXtd_GeometryDriver_Create() -> "opencascade::handle< XmlMDataXtd_GeometryDriver >":
    return _XmlMDataXtd.Handle_XmlMDataXtd_GeometryDriver_Create()

def Handle_XmlMDataXtd_GeometryDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< XmlMDataXtd_GeometryDriver >":
    return _XmlMDataXtd.Handle_XmlMDataXtd_GeometryDriver_DownCast(t)

def Handle_XmlMDataXtd_GeometryDriver_IsNull(t: "opencascade::handle< XmlMDataXtd_GeometryDriver > const &") -> "bool":
    return _XmlMDataXtd.Handle_XmlMDataXtd_GeometryDriver_IsNull(t)

def Handle_XmlMDataXtd_PatternStdDriver_Create() -> "opencascade::handle< XmlMDataXtd_PatternStdDriver >":
    return _XmlMDataXtd.Handle_XmlMDataXtd_PatternStdDriver_Create()

def Handle_XmlMDataXtd_PatternStdDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< XmlMDataXtd_PatternStdDriver >":
    return _XmlMDataXtd.Handle_XmlMDataXtd_PatternStdDriver_DownCast(t)

def Handle_XmlMDataXtd_PatternStdDriver_IsNull(t: "opencascade::handle< XmlMDataXtd_PatternStdDriver > const &") -> "bool":
    return _XmlMDataXtd.Handle_XmlMDataXtd_PatternStdDriver_IsNull(t)

def Handle_XmlMDataXtd_PositionDriver_Create() -> "opencascade::handle< XmlMDataXtd_PositionDriver >":
    return _XmlMDataXtd.Handle_XmlMDataXtd_PositionDriver_Create()

def Handle_XmlMDataXtd_PositionDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< XmlMDataXtd_PositionDriver >":
    return _XmlMDataXtd.Handle_XmlMDataXtd_PositionDriver_DownCast(t)

def Handle_XmlMDataXtd_PositionDriver_IsNull(t: "opencascade::handle< XmlMDataXtd_PositionDriver > const &") -> "bool":
    return _XmlMDataXtd.Handle_XmlMDataXtd_PositionDriver_IsNull(t)

def Handle_XmlMDataXtd_PresentationDriver_Create() -> "opencascade::handle< XmlMDataXtd_PresentationDriver >":
    return _XmlMDataXtd.Handle_XmlMDataXtd_PresentationDriver_Create()

def Handle_XmlMDataXtd_PresentationDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< XmlMDataXtd_PresentationDriver >":
    return _XmlMDataXtd.Handle_XmlMDataXtd_PresentationDriver_DownCast(t)

def Handle_XmlMDataXtd_PresentationDriver_IsNull(t: "opencascade::handle< XmlMDataXtd_PresentationDriver > const &") -> "bool":
    return _XmlMDataXtd.Handle_XmlMDataXtd_PresentationDriver_IsNull(t)

def Handle_XmlMDataXtd_TriangulationDriver_Create() -> "opencascade::handle< XmlMDataXtd_TriangulationDriver >":
    return _XmlMDataXtd.Handle_XmlMDataXtd_TriangulationDriver_Create()

def Handle_XmlMDataXtd_TriangulationDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< XmlMDataXtd_TriangulationDriver >":
    return _XmlMDataXtd.Handle_XmlMDataXtd_TriangulationDriver_DownCast(t)

def Handle_XmlMDataXtd_TriangulationDriver_IsNull(t: "opencascade::handle< XmlMDataXtd_TriangulationDriver > const &") -> "bool":
    return _XmlMDataXtd.Handle_XmlMDataXtd_TriangulationDriver_IsNull(t)
class xmlmdataxtd(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    @staticmethod
    def AddDrivers(*args) -> "void":
        r"""
        Adds the attribute drivers to <adrivertable>.

        Parameters
        ----------
        aDriverTable: XmlMDF_ADriverTable
        anMsgDrv: Message_Messenger

        Returns
        -------
        None

        """
        return _XmlMDataXtd.xmlmdataxtd_AddDrivers(*args)

    @staticmethod
    def DocumentVersion(*args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _XmlMDataXtd.xmlmdataxtd_DocumentVersion(*args)

    @staticmethod
    def SetDocumentVersion(*args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        DocVersion: int

        Returns
        -------
        None

        """
        return _XmlMDataXtd.xmlmdataxtd_SetDocumentVersion(*args)

    __repr__ = _dumps_object


    def __init__(self):
        _XmlMDataXtd.xmlmdataxtd_swiginit(self, _XmlMDataXtd.new_xmlmdataxtd())
    __swig_destroy__ = _XmlMDataXtd.delete_xmlmdataxtd

# Register xmlmdataxtd in _XmlMDataXtd:
_XmlMDataXtd.xmlmdataxtd_swigregister(xmlmdataxtd)

def xmlmdataxtd_AddDrivers(*args) -> "void":
    r"""
    Adds the attribute drivers to <adrivertable>.

    Parameters
    ----------
    aDriverTable: XmlMDF_ADriverTable
    anMsgDrv: Message_Messenger

    Returns
    -------
    None

    """
    return _XmlMDataXtd.xmlmdataxtd_AddDrivers(*args)

def xmlmdataxtd_DocumentVersion(*args) -> "Standard_Integer":
    r"""
    No available documentation.

    Returns
    -------
    int

    """
    return _XmlMDataXtd.xmlmdataxtd_DocumentVersion(*args)

def xmlmdataxtd_SetDocumentVersion(*args) -> "void":
    r"""
    No available documentation.

    Parameters
    ----------
    DocVersion: int

    Returns
    -------
    None

    """
    return _XmlMDataXtd.xmlmdataxtd_SetDocumentVersion(*args)

class XmlMDataXtd_ConstraintDriver(OCC.Core.XmlMDF.XmlMDF_ADriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        _XmlMDataXtd.XmlMDataXtd_ConstraintDriver_swiginit(self, _XmlMDataXtd.new_XmlMDataXtd_ConstraintDriver(*args))

    def Paste(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Source: XmlObjMgt_Persistent
        Target: TDF_Attribute
        RelocTable: XmlObjMgt_RRelocationTable

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        Source: TDF_Attribute
        Target: XmlObjMgt_Persistent
        RelocTable: XmlObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _XmlMDataXtd.XmlMDataXtd_ConstraintDriver_Paste(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_XmlMDataXtd_ConstraintDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _XmlMDataXtd.delete_XmlMDataXtd_ConstraintDriver

# Register XmlMDataXtd_ConstraintDriver in _XmlMDataXtd:
_XmlMDataXtd.XmlMDataXtd_ConstraintDriver_swigregister(XmlMDataXtd_ConstraintDriver)

class XmlMDataXtd_GeometryDriver(OCC.Core.XmlMDF.XmlMDF_ADriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        _XmlMDataXtd.XmlMDataXtd_GeometryDriver_swiginit(self, _XmlMDataXtd.new_XmlMDataXtd_GeometryDriver(*args))

    def Paste(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Source: XmlObjMgt_Persistent
        Target: TDF_Attribute
        RelocTable: XmlObjMgt_RRelocationTable

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        Source: TDF_Attribute
        Target: XmlObjMgt_Persistent
        RelocTable: XmlObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _XmlMDataXtd.XmlMDataXtd_GeometryDriver_Paste(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_XmlMDataXtd_GeometryDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _XmlMDataXtd.delete_XmlMDataXtd_GeometryDriver

# Register XmlMDataXtd_GeometryDriver in _XmlMDataXtd:
_XmlMDataXtd.XmlMDataXtd_GeometryDriver_swigregister(XmlMDataXtd_GeometryDriver)

class XmlMDataXtd_PatternStdDriver(OCC.Core.XmlMDF.XmlMDF_ADriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        _XmlMDataXtd.XmlMDataXtd_PatternStdDriver_swiginit(self, _XmlMDataXtd.new_XmlMDataXtd_PatternStdDriver(*args))

    def Paste(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Source: XmlObjMgt_Persistent
        Target: TDF_Attribute
        RelocTable: XmlObjMgt_RRelocationTable

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        Source: TDF_Attribute
        Target: XmlObjMgt_Persistent
        RelocTable: XmlObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _XmlMDataXtd.XmlMDataXtd_PatternStdDriver_Paste(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_XmlMDataXtd_PatternStdDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _XmlMDataXtd.delete_XmlMDataXtd_PatternStdDriver

# Register XmlMDataXtd_PatternStdDriver in _XmlMDataXtd:
_XmlMDataXtd.XmlMDataXtd_PatternStdDriver_swigregister(XmlMDataXtd_PatternStdDriver)

class XmlMDataXtd_PositionDriver(OCC.Core.XmlMDF.XmlMDF_ADriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        _XmlMDataXtd.XmlMDataXtd_PositionDriver_swiginit(self, _XmlMDataXtd.new_XmlMDataXtd_PositionDriver(*args))

    def Paste(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Source: XmlObjMgt_Persistent
        Target: TDF_Attribute
        RelocTable: XmlObjMgt_RRelocationTable

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        Source: TDF_Attribute
        Target: XmlObjMgt_Persistent
        RelocTable: XmlObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _XmlMDataXtd.XmlMDataXtd_PositionDriver_Paste(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_XmlMDataXtd_PositionDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _XmlMDataXtd.delete_XmlMDataXtd_PositionDriver

# Register XmlMDataXtd_PositionDriver in _XmlMDataXtd:
_XmlMDataXtd.XmlMDataXtd_PositionDriver_swigregister(XmlMDataXtd_PositionDriver)

class XmlMDataXtd_PresentationDriver(OCC.Core.XmlMDF.XmlMDF_ADriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        _XmlMDataXtd.XmlMDataXtd_PresentationDriver_swiginit(self, _XmlMDataXtd.new_XmlMDataXtd_PresentationDriver(*args))

    def Paste(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Source: XmlObjMgt_Persistent
        Target: TDF_Attribute
        RelocTable: XmlObjMgt_RRelocationTable

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        Source: TDF_Attribute
        Target: XmlObjMgt_Persistent
        RelocTable: XmlObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _XmlMDataXtd.XmlMDataXtd_PresentationDriver_Paste(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_XmlMDataXtd_PresentationDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _XmlMDataXtd.delete_XmlMDataXtd_PresentationDriver

# Register XmlMDataXtd_PresentationDriver in _XmlMDataXtd:
_XmlMDataXtd.XmlMDataXtd_PresentationDriver_swigregister(XmlMDataXtd_PresentationDriver)

class XmlMDataXtd_TriangulationDriver(OCC.Core.XmlMDF.XmlMDF_ADriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        _XmlMDataXtd.XmlMDataXtd_TriangulationDriver_swiginit(self, _XmlMDataXtd.new_XmlMDataXtd_TriangulationDriver(*args))

    def Paste(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Source: XmlObjMgt_Persistent
        Target: TDF_Attribute
        RelocTable: XmlObjMgt_RRelocationTable

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        Source: TDF_Attribute
        Target: XmlObjMgt_Persistent
        RelocTable: XmlObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _XmlMDataXtd.XmlMDataXtd_TriangulationDriver_Paste(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_XmlMDataXtd_TriangulationDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _XmlMDataXtd.delete_XmlMDataXtd_TriangulationDriver

# Register XmlMDataXtd_TriangulationDriver in _XmlMDataXtd:
_XmlMDataXtd.XmlMDataXtd_TriangulationDriver_swigregister(XmlMDataXtd_TriangulationDriver)








from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.Transfer import *
from OCC.Core.TopoDS import *
from OCC.Core.TCollection import *
from OCC.Core.MoniTool import *
from OCC.Core.StepShape import *
from OCC.Core.Message import *
from OCC.Core.TColStd import *


class TopoDSToStep_MakeEdgeError(IntEnum):
	TopoDSToStep_EdgeDone: int = ...
	TopoDSToStep_NonManifoldEdge: int = ...
	TopoDSToStep_EdgeOther: int = ...
TopoDSToStep_EdgeDone = TopoDSToStep_MakeEdgeError.TopoDSToStep_EdgeDone
TopoDSToStep_NonManifoldEdge = TopoDSToStep_MakeEdgeError.TopoDSToStep_NonManifoldEdge
TopoDSToStep_EdgeOther = TopoDSToStep_MakeEdgeError.TopoDSToStep_EdgeOther

class TopoDSToStep_BuilderError(IntEnum):
	TopoDSToStep_BuilderDone: int = ...
	TopoDSToStep_NoFaceMapped: int = ...
	TopoDSToStep_BuilderOther: int = ...
TopoDSToStep_BuilderDone = TopoDSToStep_BuilderError.TopoDSToStep_BuilderDone
TopoDSToStep_NoFaceMapped = TopoDSToStep_BuilderError.TopoDSToStep_NoFaceMapped
TopoDSToStep_BuilderOther = TopoDSToStep_BuilderError.TopoDSToStep_BuilderOther

class TopoDSToStep_MakeVertexError(IntEnum):
	TopoDSToStep_VertexDone: int = ...
	TopoDSToStep_VertexOther: int = ...
TopoDSToStep_VertexDone = TopoDSToStep_MakeVertexError.TopoDSToStep_VertexDone
TopoDSToStep_VertexOther = TopoDSToStep_MakeVertexError.TopoDSToStep_VertexOther

class TopoDSToStep_MakeWireError(IntEnum):
	TopoDSToStep_WireDone: int = ...
	TopoDSToStep_NonManifoldWire: int = ...
	TopoDSToStep_WireOther: int = ...
TopoDSToStep_WireDone = TopoDSToStep_MakeWireError.TopoDSToStep_WireDone
TopoDSToStep_NonManifoldWire = TopoDSToStep_MakeWireError.TopoDSToStep_NonManifoldWire
TopoDSToStep_WireOther = TopoDSToStep_MakeWireError.TopoDSToStep_WireOther

class TopoDSToStep_MakeFaceError(IntEnum):
	TopoDSToStep_FaceDone: int = ...
	TopoDSToStep_InfiniteFace: int = ...
	TopoDSToStep_NonManifoldFace: int = ...
	TopoDSToStep_NoWireMapped: int = ...
	TopoDSToStep_FaceOther: int = ...
TopoDSToStep_FaceDone = TopoDSToStep_MakeFaceError.TopoDSToStep_FaceDone
TopoDSToStep_InfiniteFace = TopoDSToStep_MakeFaceError.TopoDSToStep_InfiniteFace
TopoDSToStep_NonManifoldFace = TopoDSToStep_MakeFaceError.TopoDSToStep_NonManifoldFace
TopoDSToStep_NoWireMapped = TopoDSToStep_MakeFaceError.TopoDSToStep_NoWireMapped
TopoDSToStep_FaceOther = TopoDSToStep_MakeFaceError.TopoDSToStep_FaceOther

class TopoDSToStep_FacetedError(IntEnum):
	TopoDSToStep_FacetedDone: int = ...
	TopoDSToStep_SurfaceNotPlane: int = ...
	TopoDSToStep_PCurveNotLinear: int = ...
TopoDSToStep_FacetedDone = TopoDSToStep_FacetedError.TopoDSToStep_FacetedDone
TopoDSToStep_SurfaceNotPlane = TopoDSToStep_FacetedError.TopoDSToStep_SurfaceNotPlane
TopoDSToStep_PCurveNotLinear = TopoDSToStep_FacetedError.TopoDSToStep_PCurveNotLinear

class topodstostep:
	@overload
	@staticmethod
	def AddResult(FP: Transfer_FinderProcess, Shape: TopoDS_Shape, entity: Standard_Transient) -> None: ...
	@overload
	@staticmethod
	def AddResult(FP: Transfer_FinderProcess, Tool: TopoDSToStep_Tool) -> None: ...
	@staticmethod
	def DecodeBuilderError(E: TopoDSToStep_BuilderError) -> TCollection_HAsciiString: ...
	@staticmethod
	def DecodeEdgeError(E: TopoDSToStep_MakeEdgeError) -> TCollection_HAsciiString: ...
	@staticmethod
	def DecodeFaceError(E: TopoDSToStep_MakeFaceError) -> TCollection_HAsciiString: ...
	@staticmethod
	def DecodeVertexError(E: TopoDSToStep_MakeVertexError) -> TCollection_HAsciiString: ...
	@staticmethod
	def DecodeWireError(E: TopoDSToStep_MakeWireError) -> TCollection_HAsciiString: ...

class TopoDSToStep_FacetedTool:
	@staticmethod
	def CheckTopoDSShape(SH: TopoDS_Shape) -> TopoDSToStep_FacetedError: ...

class TopoDSToStep_Root:
	def IsDone(self) -> bool: ...
	def GetTolerance(self) -> float: ...
	def SetTolerance(self, value: float) -> None: ...

class TopoDSToStep_Tool:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, M: MoniTool_DataMapOfShapeTransient, FacetedContext: bool) -> None: ...
	def Bind(self, S: TopoDS_Shape, T: StepShape_TopologicalRepresentationItem) -> None: ...
	def CurrentEdge(self) -> TopoDS_Edge: ...
	def CurrentFace(self) -> TopoDS_Face: ...
	def CurrentShell(self) -> TopoDS_Shell: ...
	def CurrentVertex(self) -> TopoDS_Vertex: ...
	def CurrentWire(self) -> TopoDS_Wire: ...
	def Faceted(self) -> bool: ...
	def Find(self, S: TopoDS_Shape) -> StepShape_TopologicalRepresentationItem: ...
	def Init(self, M: MoniTool_DataMapOfShapeTransient, FacetedContext: bool) -> None: ...
	def IsBound(self, S: TopoDS_Shape) -> bool: ...
	def Lowest3DTolerance(self) -> float: ...
	def Map(self) -> MoniTool_DataMapOfShapeTransient: ...
	def PCurveMode(self) -> int: ...
	def SetCurrentEdge(self, E: TopoDS_Edge) -> None: ...
	def SetCurrentFace(self, F: TopoDS_Face) -> None: ...
	def SetCurrentShell(self, S: TopoDS_Shell) -> None: ...
	def SetCurrentVertex(self, V: TopoDS_Vertex) -> None: ...
	def SetCurrentWire(self, W: TopoDS_Wire) -> None: ...
	def SetSurfaceReversed(self, B: bool) -> None: ...
	def SurfaceReversed(self) -> bool: ...

class TopoDSToStep_Builder(TopoDSToStep_Root):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, S: TopoDS_Shape, T: TopoDSToStep_Tool, FP: Transfer_FinderProcess, theProgress: Optional[Message_ProgressRange] = Message_ProgressRange()) -> None: ...
	def Error(self) -> TopoDSToStep_BuilderError: ...
	def Init(self, S: TopoDS_Shape, T: TopoDSToStep_Tool, FP: Transfer_FinderProcess, theProgress: Optional[Message_ProgressRange] = Message_ProgressRange()) -> None: ...
	def Value(self) -> StepShape_TopologicalRepresentationItem: ...

class TopoDSToStep_MakeBrepWithVoids(TopoDSToStep_Root):
	def __init__(self, S: TopoDS_Solid, FP: Transfer_FinderProcess, theProgress: Optional[Message_ProgressRange] = Message_ProgressRange()) -> None: ...
	def Value(self) -> StepShape_BrepWithVoids: ...

class TopoDSToStep_MakeFacetedBrep(TopoDSToStep_Root):
	@overload
	def __init__(self, S: TopoDS_Shell, FP: Transfer_FinderProcess, theProgress: Optional[Message_ProgressRange] = Message_ProgressRange()) -> None: ...
	@overload
	def __init__(self, S: TopoDS_Solid, FP: Transfer_FinderProcess, theProgress: Optional[Message_ProgressRange] = Message_ProgressRange()) -> None: ...
	def Value(self) -> StepShape_FacetedBrep: ...

class TopoDSToStep_MakeFacetedBrepAndBrepWithVoids(TopoDSToStep_Root):
	def __init__(self, S: TopoDS_Solid, FP: Transfer_FinderProcess, theProgress: Optional[Message_ProgressRange] = Message_ProgressRange()) -> None: ...
	def Value(self) -> StepShape_FacetedBrepAndBrepWithVoids: ...

class TopoDSToStep_MakeGeometricCurveSet(TopoDSToStep_Root):
	def __init__(self, SH: TopoDS_Shape, FP: Transfer_FinderProcess) -> None: ...
	def Value(self) -> StepShape_GeometricCurveSet: ...

class TopoDSToStep_MakeManifoldSolidBrep(TopoDSToStep_Root):
	@overload
	def __init__(self, S: TopoDS_Shell, FP: Transfer_FinderProcess, theProgress: Optional[Message_ProgressRange] = Message_ProgressRange()) -> None: ...
	@overload
	def __init__(self, S: TopoDS_Solid, FP: Transfer_FinderProcess, theProgress: Optional[Message_ProgressRange] = Message_ProgressRange()) -> None: ...
	def Value(self) -> StepShape_ManifoldSolidBrep: ...

class TopoDSToStep_MakeShellBasedSurfaceModel(TopoDSToStep_Root):
	@overload
	def __init__(self, F: TopoDS_Face, FP: Transfer_FinderProcess, theProgress: Optional[Message_ProgressRange] = Message_ProgressRange()) -> None: ...
	@overload
	def __init__(self, S: TopoDS_Shell, FP: Transfer_FinderProcess, theProgress: Optional[Message_ProgressRange] = Message_ProgressRange()) -> None: ...
	@overload
	def __init__(self, S: TopoDS_Solid, FP: Transfer_FinderProcess, theProgress: Optional[Message_ProgressRange] = Message_ProgressRange()) -> None: ...
	def Value(self) -> StepShape_ShellBasedSurfaceModel: ...

class TopoDSToStep_MakeStepEdge(TopoDSToStep_Root):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, E: TopoDS_Edge, T: TopoDSToStep_Tool, FP: Transfer_FinderProcess) -> None: ...
	def Error(self) -> TopoDSToStep_MakeEdgeError: ...
	def Init(self, E: TopoDS_Edge, T: TopoDSToStep_Tool, FP: Transfer_FinderProcess) -> None: ...
	def Value(self) -> StepShape_TopologicalRepresentationItem: ...

class TopoDSToStep_MakeStepFace(TopoDSToStep_Root):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, F: TopoDS_Face, T: TopoDSToStep_Tool, FP: Transfer_FinderProcess) -> None: ...
	def Error(self) -> TopoDSToStep_MakeFaceError: ...
	def Init(self, F: TopoDS_Face, T: TopoDSToStep_Tool, FP: Transfer_FinderProcess) -> None: ...
	def Value(self) -> StepShape_TopologicalRepresentationItem: ...

class TopoDSToStep_MakeStepVertex(TopoDSToStep_Root):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, V: TopoDS_Vertex, T: TopoDSToStep_Tool, FP: Transfer_FinderProcess) -> None: ...
	def Error(self) -> TopoDSToStep_MakeVertexError: ...
	def Init(self, V: TopoDS_Vertex, T: TopoDSToStep_Tool, FP: Transfer_FinderProcess) -> None: ...
	def Value(self) -> StepShape_TopologicalRepresentationItem: ...

class TopoDSToStep_MakeStepWire(TopoDSToStep_Root):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, W: TopoDS_Wire, T: TopoDSToStep_Tool, FP: Transfer_FinderProcess) -> None: ...
	def Error(self) -> TopoDSToStep_MakeWireError: ...
	def Init(self, W: TopoDS_Wire, T: TopoDSToStep_Tool, FP: Transfer_FinderProcess) -> None: ...
	def Value(self) -> StepShape_TopologicalRepresentationItem: ...

class TopoDSToStep_WireframeBuilder(TopoDSToStep_Root):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, S: TopoDS_Shape, T: TopoDSToStep_Tool, FP: Transfer_FinderProcess) -> None: ...
	def Error(self) -> TopoDSToStep_BuilderError: ...
	def GetTrimmedCurveFromEdge(self, E: TopoDS_Edge, F: TopoDS_Face, M: MoniTool_DataMapOfShapeTransient, L: TColStd_HSequenceOfTransient) -> bool: ...
	def GetTrimmedCurveFromFace(self, F: TopoDS_Face, M: MoniTool_DataMapOfShapeTransient, L: TColStd_HSequenceOfTransient) -> bool: ...
	def GetTrimmedCurveFromShape(self, S: TopoDS_Shape, M: MoniTool_DataMapOfShapeTransient, L: TColStd_HSequenceOfTransient) -> bool: ...
	def Init(self, S: TopoDS_Shape, T: TopoDSToStep_Tool, FP: Transfer_FinderProcess) -> None: ...
	def Value(self) -> TColStd_HSequenceOfTransient: ...

# harray1 classes
# harray2 classes
# hsequence classes

topodstostep_AddResult = topodstostep.AddResult
topodstostep_AddResult = topodstostep.AddResult
topodstostep_DecodeBuilderError = topodstostep.DecodeBuilderError
topodstostep_DecodeEdgeError = topodstostep.DecodeEdgeError
topodstostep_DecodeFaceError = topodstostep.DecodeFaceError
topodstostep_DecodeVertexError = topodstostep.DecodeVertexError
topodstostep_DecodeWireError = topodstostep.DecodeWireError
TopoDSToStep_FacetedTool_CheckTopoDSShape = TopoDSToStep_FacetedTool.CheckTopoDSShape



from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.IGESData import *
from OCC.Core.TColStd import *
from OCC.Core.TopoDS import *
from OCC.Core.Transfer import *
from OCC.Core.Interface import *
from OCC.Core.Message import *
from OCC.Core.Geom import *
from OCC.Core.gp import *
from OCC.Core.ShapeExtend import *
from OCC.Core.Geom2d import *


class igestobrep:
	@staticmethod
	def AlgoContainer() -> IGESToBRep_AlgoContainer: ...
	@staticmethod
	def IGESCurveToSequenceOfIGESCurve(curve: IGESData_IGESEntity, sequence: TColStd_HSequenceOfTransient) -> int: ...
	@staticmethod
	def Init() -> None: ...
	@staticmethod
	def IsBRepEntity(start: IGESData_IGESEntity) -> bool: ...
	@staticmethod
	def IsBasicCurve(start: IGESData_IGESEntity) -> bool: ...
	@staticmethod
	def IsBasicSurface(start: IGESData_IGESEntity) -> bool: ...
	@staticmethod
	def IsCurveAndSurface(start: IGESData_IGESEntity) -> bool: ...
	@staticmethod
	def IsTopoCurve(start: IGESData_IGESEntity) -> bool: ...
	@staticmethod
	def IsTopoSurface(start: IGESData_IGESEntity) -> bool: ...
	@staticmethod
	def SetAlgoContainer(aContainer: IGESToBRep_AlgoContainer) -> None: ...
	@staticmethod
	def TransferPCurve(fromedge: TopoDS_Edge, toedge: TopoDS_Edge, face: TopoDS_Face) -> bool: ...

class IGESToBRep_Actor(Transfer_ActorOfTransientProcess):
	def __init__(self) -> None: ...
	def GetContinuity(self) -> int: ...
	def Recognize(self, start: Standard_Transient) -> bool: ...
	def SetContinuity(self, continuity: Optional[int] = 0) -> None: ...
	def SetModel(self, model: Interface_InterfaceModel) -> None: ...
	def Transfer(self, start: Standard_Transient, TP: Transfer_TransientProcess, theProgress: Optional[Message_ProgressRange] = Message_ProgressRange()) -> Transfer_Binder: ...
	def UsedTolerance(self) -> float: ...

class IGESToBRep_AlgoContainer(Standard_Transient):
	def __init__(self) -> None: ...
	def SetToolContainer(self, TC: IGESToBRep_ToolContainer) -> None: ...
	def ToolContainer(self) -> IGESToBRep_ToolContainer: ...

class IGESToBRep_CurveAndSurface:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, eps: float, epsGeom: float, epsCoeff: float, mode: bool, modeapprox: bool, optimized: bool) -> None: ...
	def AddShapeResult(self, start: IGESData_IGESEntity, result: TopoDS_Shape) -> None: ...
	def GetContinuity(self) -> int: ...
	def GetEpsCoeff(self) -> float: ...
	def GetEpsGeom(self) -> float: ...
	def GetEpsilon(self) -> float: ...
	def GetMaxTol(self) -> float: ...
	def GetMinTol(self) -> float: ...
	def GetModeApprox(self) -> bool: ...
	def GetModeTransfer(self) -> bool: ...
	def GetModel(self) -> IGESData_IGESModel: ...
	def GetOptimized(self) -> bool: ...
	@overload
	def GetShapeResult(self, start: IGESData_IGESEntity) -> TopoDS_Shape: ...
	@overload
	def GetShapeResult(self, start: IGESData_IGESEntity, num: int) -> TopoDS_Shape: ...
	def GetSurfaceCurve(self) -> int: ...
	def GetTransferProcess(self) -> Transfer_TransientProcess: ...
	def GetUVResolution(self) -> float: ...
	def GetUnitFactor(self) -> float: ...
	def HasShapeResult(self, start: IGESData_IGESEntity) -> bool: ...
	def Init(self) -> None: ...
	def NbShapeResult(self, start: IGESData_IGESEntity) -> int: ...
	def SendFail(self, start: IGESData_IGESEntity, amsg: Message_Msg) -> None: ...
	def SendMsg(self, start: IGESData_IGESEntity, amsg: Message_Msg) -> None: ...
	def SendWarning(self, start: IGESData_IGESEntity, amsg: Message_Msg) -> None: ...
	def SetContinuity(self, continuity: int) -> None: ...
	def SetEpsCoeff(self, eps: float) -> None: ...
	def SetEpsGeom(self, eps: float) -> None: ...
	def SetEpsilon(self, eps: float) -> None: ...
	def SetMaxTol(self, maxtol: float) -> None: ...
	def SetMinTol(self, mintol: float) -> None: ...
	def SetModeApprox(self, mode: bool) -> None: ...
	def SetModeTransfer(self, mode: bool) -> None: ...
	def SetModel(self, model: IGESData_IGESModel) -> None: ...
	def SetOptimized(self, optimized: bool) -> None: ...
	def SetShapeResult(self, start: IGESData_IGESEntity, result: TopoDS_Shape) -> None: ...
	def SetSurface(self, theSurface: Geom_Surface) -> None: ...
	def SetSurfaceCurve(self, ival: int) -> None: ...
	def SetTransferProcess(self, TP: Transfer_TransientProcess) -> None: ...
	def Surface(self) -> Geom_Surface: ...
	def TransferCurveAndSurface(self, start: IGESData_IGESEntity, theProgress: Optional[Message_ProgressRange] = Message_ProgressRange()) -> TopoDS_Shape: ...
	def TransferGeometry(self, start: IGESData_IGESEntity, theProgress: Optional[Message_ProgressRange] = Message_ProgressRange()) -> TopoDS_Shape: ...
	def UpdateMinMaxTol(self) -> None: ...

class IGESToBRep_IGESBoundary(Standard_Transient):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, CS: IGESToBRep_CurveAndSurface) -> None: ...
	def Check(self, result: bool, checkclosure: bool, okCurve3d: bool, okCurve2d: bool) -> None: ...
	def Init(self, CS: IGESToBRep_CurveAndSurface, entity: IGESData_IGESEntity, face: TopoDS_Face, trans: gp_Trsf2d, uFact: float, filepreference: int) -> None: ...
	@overload
	def Transfer(self, curve3d: IGESData_IGESEntity, toreverse3d: bool, curves2d: IGESData_HArray1OfIGESEntity, number: int) -> Tuple[bool, bool, bool, bool]: ...
	@overload
	def Transfer(self, curve3d: ShapeExtend_WireData, curves2d: IGESData_HArray1OfIGESEntity, toreverse2d: bool, number: int, lsewd: ShapeExtend_WireData) -> Tuple[bool, bool, bool, bool]: ...
	def WireData(self) -> ShapeExtend_WireData: ...
	def WireData2d(self) -> ShapeExtend_WireData: ...
	def WireData3d(self) -> ShapeExtend_WireData: ...

class IGESToBRep_Reader:
	def __init__(self) -> None: ...
	def Actor(self) -> IGESToBRep_Actor: ...
	def Check(self, withprint: bool) -> bool: ...
	def Clear(self) -> None: ...
	def IsDone(self) -> bool: ...
	def LoadFile(self, filename: str) -> int: ...
	def Model(self) -> IGESData_IGESModel: ...
	def NbShapes(self) -> int: ...
	def OneShape(self) -> TopoDS_Shape: ...
	def SetModel(self, model: IGESData_IGESModel) -> None: ...
	def SetTransientProcess(self, TP: Transfer_TransientProcess) -> None: ...
	def Shape(self, num: Optional[int] = 1) -> TopoDS_Shape: ...
	def Transfer(self, num: int, theProgress: Optional[Message_ProgressRange] = Message_ProgressRange()) -> bool: ...
	def TransferRoots(self, onlyvisible: Optional[bool] = True, theProgress: Optional[Message_ProgressRange] = Message_ProgressRange()) -> None: ...
	def TransientProcess(self) -> Transfer_TransientProcess: ...
	def UsedTolerance(self) -> float: ...

class IGESToBRep_ToolContainer(Standard_Transient):
	def __init__(self) -> None: ...
	def IGESBoundary(self) -> IGESToBRep_IGESBoundary: ...

class IGESToBRep_BRepEntity(IGESToBRep_CurveAndSurface):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, CS: IGESToBRep_CurveAndSurface) -> None: ...
	@overload
	def __init__(self, eps: float, epsGeom: float, epsCoeff: float, mode: bool, modeapprox: bool, optimized: bool) -> None: ...
	def TransferBRepEntity(self, start: IGESData_IGESEntity, theProgress: Optional[Message_ProgressRange] = Message_ProgressRange()) -> TopoDS_Shape: ...

class IGESToBRep_BasicCurve(IGESToBRep_CurveAndSurface):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, CS: IGESToBRep_CurveAndSurface) -> None: ...
	@overload
	def __init__(self, eps: float, epsGeom: float, epsCoeff: float, mode: bool, modeapprox: bool, optimized: bool) -> None: ...
	def Transfer2dBasicCurve(self, start: IGESData_IGESEntity) -> Geom2d_Curve: ...
	def TransferBasicCurve(self, start: IGESData_IGESEntity) -> Geom_Curve: ...

class IGESToBRep_BasicSurface(IGESToBRep_CurveAndSurface):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, CS: IGESToBRep_CurveAndSurface) -> None: ...
	@overload
	def __init__(self, eps: float, epsGeom: float, epsCoeff: float, mode: bool, modeapprox: bool, optimized: bool) -> None: ...
	def TransferBasicSurface(self, start: IGESData_IGESEntity) -> Geom_Surface: ...

class IGESToBRep_TopoCurve(IGESToBRep_CurveAndSurface):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, CS: IGESToBRep_CurveAndSurface) -> None: ...
	@overload
	def __init__(self, CS: IGESToBRep_TopoCurve) -> None: ...
	@overload
	def __init__(self, eps: float, epsGeom: float, epsCoeff: float, mode: bool, modeapprox: bool, optimized: bool) -> None: ...
	def Approx2dBSplineCurve(self, start: Geom2d_BSplineCurve) -> None: ...
	def ApproxBSplineCurve(self, start: Geom_BSplineCurve) -> None: ...
	def BadCase(self) -> bool: ...
	def Curve(self, num: Optional[int] = 1) -> Geom_Curve: ...
	def Curve2d(self, num: Optional[int] = 1) -> Geom2d_Curve: ...
	def NbCurves(self) -> int: ...
	def NbCurves2d(self) -> int: ...
	def SetBadCase(self, value: bool) -> None: ...
	def Transfer2dTopoBasicCurve(self, start: IGESData_IGESEntity, face: TopoDS_Face, trans: gp_Trsf2d, uFact: float) -> TopoDS_Shape: ...
	def Transfer2dTopoCurve(self, start: IGESData_IGESEntity, face: TopoDS_Face, trans: gp_Trsf2d, uFact: float) -> TopoDS_Shape: ...
	def TransferTopoBasicCurve(self, start: IGESData_IGESEntity) -> TopoDS_Shape: ...
	def TransferTopoCurve(self, start: IGESData_IGESEntity) -> TopoDS_Shape: ...

class IGESToBRep_TopoSurface(IGESToBRep_CurveAndSurface):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, CS: IGESToBRep_CurveAndSurface) -> None: ...
	@overload
	def __init__(self, eps: float, epsGeom: float, epsCoeff: float, mode: bool, modeapprox: bool, optimized: bool) -> None: ...
	def ParamSurface(self, start: IGESData_IGESEntity, trans: gp_Trsf2d) -> Tuple[TopoDS_Shape, float]: ...
	def TransferTopoBasicSurface(self, start: IGESData_IGESEntity) -> TopoDS_Shape: ...
	def TransferTopoSurface(self, start: IGESData_IGESEntity) -> TopoDS_Shape: ...

# harray1 classes
# harray2 classes
# hsequence classes

igestobrep_AlgoContainer = igestobrep.AlgoContainer
igestobrep_IGESCurveToSequenceOfIGESCurve = igestobrep.IGESCurveToSequenceOfIGESCurve
igestobrep_Init = igestobrep.Init
igestobrep_IsBRepEntity = igestobrep.IsBRepEntity
igestobrep_IsBasicCurve = igestobrep.IsBasicCurve
igestobrep_IsBasicSurface = igestobrep.IsBasicSurface
igestobrep_IsCurveAndSurface = igestobrep.IsCurveAndSurface
igestobrep_IsTopoCurve = igestobrep.IsTopoCurve
igestobrep_IsTopoSurface = igestobrep.IsTopoSurface
igestobrep_SetAlgoContainer = igestobrep.SetAlgoContainer
igestobrep_TransferPCurve = igestobrep.TransferPCurve



# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
Adaptor2d module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_adaptor2d.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _Adaptor2d
else:
    import _Adaptor2d

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _Adaptor2d.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _Adaptor2d.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _Adaptor2d.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _Adaptor2d.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _Adaptor2d.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _Adaptor2d.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _Adaptor2d.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _Adaptor2d.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _Adaptor2d.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _Adaptor2d.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _Adaptor2d.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _Adaptor2d.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _Adaptor2d.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _Adaptor2d.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _Adaptor2d.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _Adaptor2d.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _Adaptor2d.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _Adaptor2d:
_Adaptor2d.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _Adaptor2d.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.Geom2d
import OCC.Core.gp
import OCC.Core.TColStd
import OCC.Core.TCollection
import OCC.Core.GeomAbs
import OCC.Core.TColgp

from enum import IntEnum
from OCC.Core.Exception import *




def Handle_Adaptor2d_HCurve2d_Create() -> "opencascade::handle< Adaptor2d_HCurve2d >":
    return _Adaptor2d.Handle_Adaptor2d_HCurve2d_Create()

def Handle_Adaptor2d_HCurve2d_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< Adaptor2d_HCurve2d >":
    return _Adaptor2d.Handle_Adaptor2d_HCurve2d_DownCast(t)

def Handle_Adaptor2d_HCurve2d_IsNull(t: "opencascade::handle< Adaptor2d_HCurve2d > const &") -> "bool":
    return _Adaptor2d.Handle_Adaptor2d_HCurve2d_IsNull(t)

def Handle_Adaptor2d_HLine2d_Create() -> "opencascade::handle< Adaptor2d_HLine2d >":
    return _Adaptor2d.Handle_Adaptor2d_HLine2d_Create()

def Handle_Adaptor2d_HLine2d_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< Adaptor2d_HLine2d >":
    return _Adaptor2d.Handle_Adaptor2d_HLine2d_DownCast(t)

def Handle_Adaptor2d_HLine2d_IsNull(t: "opencascade::handle< Adaptor2d_HLine2d > const &") -> "bool":
    return _Adaptor2d.Handle_Adaptor2d_HLine2d_IsNull(t)

def Handle_Adaptor2d_HOffsetCurve_Create() -> "opencascade::handle< Adaptor2d_HOffsetCurve >":
    return _Adaptor2d.Handle_Adaptor2d_HOffsetCurve_Create()

def Handle_Adaptor2d_HOffsetCurve_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< Adaptor2d_HOffsetCurve >":
    return _Adaptor2d.Handle_Adaptor2d_HOffsetCurve_DownCast(t)

def Handle_Adaptor2d_HOffsetCurve_IsNull(t: "opencascade::handle< Adaptor2d_HOffsetCurve > const &") -> "bool":
    return _Adaptor2d.Handle_Adaptor2d_HOffsetCurve_IsNull(t)
class Adaptor2d_Curve2d(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def BSpline(self, *args) -> "opencascade::handle< Geom2d_BSplineCurve >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<Geom2d_BSplineCurve>

        """
        return _Adaptor2d.Adaptor2d_Curve2d_BSpline(self, *args)

    def Bezier(self, *args) -> "opencascade::handle< Geom2d_BezierCurve >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<Geom2d_BezierCurve>

        """
        return _Adaptor2d.Adaptor2d_Curve2d_Bezier(self, *args)

    def Circle(self, *args) -> "gp_Circ2d":
        r"""
        No available documentation.

        Returns
        -------
        gp_Circ2d

        """
        return _Adaptor2d.Adaptor2d_Curve2d_Circle(self, *args)

    def Continuity(self, *args) -> "GeomAbs_Shape":
        r"""
        No available documentation.

        Returns
        -------
        GeomAbs_Shape

        """
        return _Adaptor2d.Adaptor2d_Curve2d_Continuity(self, *args)

    def D0(self, *args) -> "void":
        r"""
        Computes the point of parameter u on the curve.

        Parameters
        ----------
        U: float
        P: gp_Pnt2d

        Returns
        -------
        None

        """
        return _Adaptor2d.Adaptor2d_Curve2d_D0(self, *args)

    def D1(self, *args) -> "void":
        r"""
        Computes the point of parameter u on the curve with its first derivative. raised if the continuity of the current interval is not c1.

        Parameters
        ----------
        U: float
        P: gp_Pnt2d
        V: gp_Vec2d

        Returns
        -------
        None

        """
        return _Adaptor2d.Adaptor2d_Curve2d_D1(self, *args)

    def D2(self, *args) -> "void":
        r"""
        Returns the point p of parameter u, the first and second derivatives v1 and v2. raised if the continuity of the current interval is not c2.

        Parameters
        ----------
        U: float
        P: gp_Pnt2d
        V1: gp_Vec2d
        V2: gp_Vec2d

        Returns
        -------
        None

        """
        return _Adaptor2d.Adaptor2d_Curve2d_D2(self, *args)

    def D3(self, *args) -> "void":
        r"""
        Returns the point p of parameter u, the first, the second and the third derivative. raised if the continuity of the current interval is not c3.

        Parameters
        ----------
        U: float
        P: gp_Pnt2d
        V1: gp_Vec2d
        V2: gp_Vec2d
        V3: gp_Vec2d

        Returns
        -------
        None

        """
        return _Adaptor2d.Adaptor2d_Curve2d_D3(self, *args)

    def DN(self, *args) -> "gp_Vec2d":
        r"""
        The returned vector gives the value of the derivative for the order of derivation n. raised if the continuity of the current interval is not cn. raised if n < 1.

        Parameters
        ----------
        U: float
        N: int

        Returns
        -------
        gp_Vec2d

        """
        return _Adaptor2d.Adaptor2d_Curve2d_DN(self, *args)

    def Degree(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _Adaptor2d.Adaptor2d_Curve2d_Degree(self, *args)

    def Ellipse(self, *args) -> "gp_Elips2d":
        r"""
        No available documentation.

        Returns
        -------
        gp_Elips2d

        """
        return _Adaptor2d.Adaptor2d_Curve2d_Ellipse(self, *args)

    def FirstParameter(self, *args) -> "Standard_Real":
        r"""
        No available documentation.

        Returns
        -------
        float

        """
        return _Adaptor2d.Adaptor2d_Curve2d_FirstParameter(self, *args)

    def GetType(self, *args) -> "GeomAbs_CurveType":
        r"""
        Returns the type of the curve in the current interval : line, circle, ellipse, hyperbola, parabola, beziercurve, bsplinecurve, othercurve.

        Returns
        -------
        GeomAbs_CurveType

        """
        return _Adaptor2d.Adaptor2d_Curve2d_GetType(self, *args)

    def Hyperbola(self, *args) -> "gp_Hypr2d":
        r"""
        No available documentation.

        Returns
        -------
        gp_Hypr2d

        """
        return _Adaptor2d.Adaptor2d_Curve2d_Hyperbola(self, *args)

    def Intervals(self, *args) -> "void":
        r"""
        Stores in <t> the parameters bounding the intervals of continuity <s>. //! the array must provide enough room to accomodate for the parameters. i.e. t.length() > nbintervals().

        Parameters
        ----------
        T: TColStd_Array1OfReal
        S: GeomAbs_Shape

        Returns
        -------
        None

        """
        return _Adaptor2d.Adaptor2d_Curve2d_Intervals(self, *args)

    def IsClosed(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _Adaptor2d.Adaptor2d_Curve2d_IsClosed(self, *args)

    def IsPeriodic(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _Adaptor2d.Adaptor2d_Curve2d_IsPeriodic(self, *args)

    def IsRational(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _Adaptor2d.Adaptor2d_Curve2d_IsRational(self, *args)

    def LastParameter(self, *args) -> "Standard_Real":
        r"""
        No available documentation.

        Returns
        -------
        float

        """
        return _Adaptor2d.Adaptor2d_Curve2d_LastParameter(self, *args)

    def Line(self, *args) -> "gp_Lin2d":
        r"""
        No available documentation.

        Returns
        -------
        gp_Lin2d

        """
        return _Adaptor2d.Adaptor2d_Curve2d_Line(self, *args)

    def NbIntervals(self, *args) -> "Standard_Integer":
        r"""
        If necessary, breaks the curve in intervals of continuity <s>. and returns the number of intervals.

        Parameters
        ----------
        S: GeomAbs_Shape

        Returns
        -------
        int

        """
        return _Adaptor2d.Adaptor2d_Curve2d_NbIntervals(self, *args)

    def NbKnots(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _Adaptor2d.Adaptor2d_Curve2d_NbKnots(self, *args)

    def NbPoles(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _Adaptor2d.Adaptor2d_Curve2d_NbPoles(self, *args)

    def NbSamples(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _Adaptor2d.Adaptor2d_Curve2d_NbSamples(self, *args)

    def Parabola(self, *args) -> "gp_Parab2d":
        r"""
        No available documentation.

        Returns
        -------
        gp_Parab2d

        """
        return _Adaptor2d.Adaptor2d_Curve2d_Parabola(self, *args)

    def Period(self, *args) -> "Standard_Real":
        r"""
        No available documentation.

        Returns
        -------
        float

        """
        return _Adaptor2d.Adaptor2d_Curve2d_Period(self, *args)

    def Resolution(self, *args) -> "Standard_Real":
        r"""
        Returns the parametric resolution corresponding to the real space resolution <r3d>.

        Parameters
        ----------
        R3d: float

        Returns
        -------
        float

        """
        return _Adaptor2d.Adaptor2d_Curve2d_Resolution(self, *args)

    def Trim(self, *args) -> "opencascade::handle< Adaptor2d_HCurve2d >":
        r"""
        Returns a curve equivalent of <self> between parameters <first> and <last>. <tol> is used to test for 3d points confusion. if <first> >= <last>.

        Parameters
        ----------
        First: float
        Last: float
        Tol: float

        Returns
        -------
        opencascade::handle<Adaptor2d_HCurve2d>

        """
        return _Adaptor2d.Adaptor2d_Curve2d_Trim(self, *args)

    def Value(self, *args) -> "gp_Pnt2d":
        r"""
        Computes the point of parameter u on the curve.

        Parameters
        ----------
        U: float

        Returns
        -------
        gp_Pnt2d

        """
        return _Adaptor2d.Adaptor2d_Curve2d_Value(self, *args)

    __repr__ = _dumps_object


    def __init__(self):
        _Adaptor2d.Adaptor2d_Curve2d_swiginit(self, _Adaptor2d.new_Adaptor2d_Curve2d())
    __swig_destroy__ = _Adaptor2d.delete_Adaptor2d_Curve2d

# Register Adaptor2d_Curve2d in _Adaptor2d:
_Adaptor2d.Adaptor2d_Curve2d_swigregister(Adaptor2d_Curve2d)

class Adaptor2d_HCurve2d(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def BSpline(self, *args) -> "opencascade::handle< Geom2d_BSplineCurve >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<Geom2d_BSplineCurve>

        """
        return _Adaptor2d.Adaptor2d_HCurve2d_BSpline(self, *args)

    def Bezier(self, *args) -> "opencascade::handle< Geom2d_BezierCurve >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<Geom2d_BezierCurve>

        """
        return _Adaptor2d.Adaptor2d_HCurve2d_Bezier(self, *args)

    def Circle(self, *args) -> "gp_Circ2d":
        r"""
        No available documentation.

        Returns
        -------
        gp_Circ2d

        """
        return _Adaptor2d.Adaptor2d_HCurve2d_Circle(self, *args)

    def Continuity(self, *args) -> "GeomAbs_Shape":
        r"""
        No available documentation.

        Returns
        -------
        GeomAbs_Shape

        """
        return _Adaptor2d.Adaptor2d_HCurve2d_Continuity(self, *args)

    def Curve2d(self, *args) -> "Adaptor2d_Curve2d const &":
        r"""
        Returns a reference to the curve2d inside the hcurve2d.

        Returns
        -------
        Adaptor2d_Curve2d

        """
        return _Adaptor2d.Adaptor2d_HCurve2d_Curve2d(self, *args)

    def D0(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        U: float
        P: gp_Pnt2d

        Returns
        -------
        None

        """
        return _Adaptor2d.Adaptor2d_HCurve2d_D0(self, *args)

    def D1(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        U: float
        P: gp_Pnt2d
        V: gp_Vec2d

        Returns
        -------
        None

        """
        return _Adaptor2d.Adaptor2d_HCurve2d_D1(self, *args)

    def D2(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        U: float
        P: gp_Pnt2d
        V1: gp_Vec2d
        V2: gp_Vec2d

        Returns
        -------
        None

        """
        return _Adaptor2d.Adaptor2d_HCurve2d_D2(self, *args)

    def D3(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        U: float
        P: gp_Pnt2d
        V1: gp_Vec2d
        V2: gp_Vec2d
        V3: gp_Vec2d

        Returns
        -------
        None

        """
        return _Adaptor2d.Adaptor2d_HCurve2d_D3(self, *args)

    def DN(self, *args) -> "gp_Vec2d":
        r"""
        No available documentation.

        Parameters
        ----------
        U: float
        N: int

        Returns
        -------
        gp_Vec2d

        """
        return _Adaptor2d.Adaptor2d_HCurve2d_DN(self, *args)

    def Degree(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _Adaptor2d.Adaptor2d_HCurve2d_Degree(self, *args)

    def Ellipse(self, *args) -> "gp_Elips2d":
        r"""
        No available documentation.

        Returns
        -------
        gp_Elips2d

        """
        return _Adaptor2d.Adaptor2d_HCurve2d_Ellipse(self, *args)

    def FirstParameter(self, *args) -> "Standard_Real":
        r"""
        No available documentation.

        Returns
        -------
        float

        """
        return _Adaptor2d.Adaptor2d_HCurve2d_FirstParameter(self, *args)

    def GetType(self, *args) -> "GeomAbs_CurveType":
        r"""
        No available documentation.

        Returns
        -------
        GeomAbs_CurveType

        """
        return _Adaptor2d.Adaptor2d_HCurve2d_GetType(self, *args)

    def Hyperbola(self, *args) -> "gp_Hypr2d":
        r"""
        No available documentation.

        Returns
        -------
        gp_Hypr2d

        """
        return _Adaptor2d.Adaptor2d_HCurve2d_Hyperbola(self, *args)

    def Intervals(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        T: TColStd_Array1OfReal
        S: GeomAbs_Shape

        Returns
        -------
        None

        """
        return _Adaptor2d.Adaptor2d_HCurve2d_Intervals(self, *args)

    def IsClosed(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _Adaptor2d.Adaptor2d_HCurve2d_IsClosed(self, *args)

    def IsPeriodic(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _Adaptor2d.Adaptor2d_HCurve2d_IsPeriodic(self, *args)

    def IsRational(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _Adaptor2d.Adaptor2d_HCurve2d_IsRational(self, *args)

    def LastParameter(self, *args) -> "Standard_Real":
        r"""
        No available documentation.

        Returns
        -------
        float

        """
        return _Adaptor2d.Adaptor2d_HCurve2d_LastParameter(self, *args)

    def Line(self, *args) -> "gp_Lin2d":
        r"""
        No available documentation.

        Returns
        -------
        gp_Lin2d

        """
        return _Adaptor2d.Adaptor2d_HCurve2d_Line(self, *args)

    def NbIntervals(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Parameters
        ----------
        S: GeomAbs_Shape

        Returns
        -------
        int

        """
        return _Adaptor2d.Adaptor2d_HCurve2d_NbIntervals(self, *args)

    def NbKnots(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _Adaptor2d.Adaptor2d_HCurve2d_NbKnots(self, *args)

    def NbPoles(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _Adaptor2d.Adaptor2d_HCurve2d_NbPoles(self, *args)

    def Parabola(self, *args) -> "gp_Parab2d":
        r"""
        No available documentation.

        Returns
        -------
        gp_Parab2d

        """
        return _Adaptor2d.Adaptor2d_HCurve2d_Parabola(self, *args)

    def Period(self, *args) -> "Standard_Real":
        r"""
        No available documentation.

        Returns
        -------
        float

        """
        return _Adaptor2d.Adaptor2d_HCurve2d_Period(self, *args)

    def Resolution(self, *args) -> "Standard_Real":
        r"""
        No available documentation.

        Parameters
        ----------
        R3d: float

        Returns
        -------
        float

        """
        return _Adaptor2d.Adaptor2d_HCurve2d_Resolution(self, *args)

    def Trim(self, *args) -> "opencascade::handle< Adaptor2d_HCurve2d >":
        r"""
        If <first> >= <last>.

        Parameters
        ----------
        First: float
        Last: float
        Tol: float

        Returns
        -------
        opencascade::handle<Adaptor2d_HCurve2d>

        """
        return _Adaptor2d.Adaptor2d_HCurve2d_Trim(self, *args)

    def Value(self, *args) -> "gp_Pnt2d":
        r"""
        No available documentation.

        Parameters
        ----------
        U: float

        Returns
        -------
        gp_Pnt2d

        """
        return _Adaptor2d.Adaptor2d_HCurve2d_Value(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_Adaptor2d_HCurve2d_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _Adaptor2d.delete_Adaptor2d_HCurve2d

# Register Adaptor2d_HCurve2d in _Adaptor2d:
_Adaptor2d.Adaptor2d_HCurve2d_swigregister(Adaptor2d_HCurve2d)

class Adaptor2d_HLine2d(Adaptor2d_HCurve2d):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Creates an empty genhcurve2d.

        Returns
        -------
        None
        Creates a genhcurve2d from a curve.

        Parameters
        ----------
        C: Adaptor2d_Line2d

        Returns
        -------
        None

        """
        _Adaptor2d.Adaptor2d_HLine2d_swiginit(self, _Adaptor2d.new_Adaptor2d_HLine2d(*args))

    def ChangeCurve2d(self, *args) -> "Adaptor2d_Line2d &":
        r"""
        Returns the curve used to create the genhcurve.

        Returns
        -------
        Adaptor2d_Line2d

        """
        return _Adaptor2d.Adaptor2d_HLine2d_ChangeCurve2d(self, *args)

    def Set(self, *args) -> "void":
        r"""
        Sets the field of the genhcurve2d.

        Parameters
        ----------
        C: Adaptor2d_Line2d

        Returns
        -------
        None

        """
        return _Adaptor2d.Adaptor2d_HLine2d_Set(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_Adaptor2d_HLine2d_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _Adaptor2d.delete_Adaptor2d_HLine2d

# Register Adaptor2d_HLine2d in _Adaptor2d:
_Adaptor2d.Adaptor2d_HLine2d_swigregister(Adaptor2d_HLine2d)

class Adaptor2d_HOffsetCurve(Adaptor2d_HCurve2d):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Creates an empty genhcurve2d.

        Returns
        -------
        None
        Creates a genhcurve2d from a curve.

        Parameters
        ----------
        C: Adaptor2d_OffsetCurve

        Returns
        -------
        None

        """
        _Adaptor2d.Adaptor2d_HOffsetCurve_swiginit(self, _Adaptor2d.new_Adaptor2d_HOffsetCurve(*args))

    def ChangeCurve2d(self, *args) -> "Adaptor2d_OffsetCurve &":
        r"""
        Returns the curve used to create the genhcurve.

        Returns
        -------
        Adaptor2d_OffsetCurve

        """
        return _Adaptor2d.Adaptor2d_HOffsetCurve_ChangeCurve2d(self, *args)

    def Set(self, *args) -> "void":
        r"""
        Sets the field of the genhcurve2d.

        Parameters
        ----------
        C: Adaptor2d_OffsetCurve

        Returns
        -------
        None

        """
        return _Adaptor2d.Adaptor2d_HOffsetCurve_Set(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_Adaptor2d_HOffsetCurve_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _Adaptor2d.delete_Adaptor2d_HOffsetCurve

# Register Adaptor2d_HOffsetCurve in _Adaptor2d:
_Adaptor2d.Adaptor2d_HOffsetCurve_swigregister(Adaptor2d_HOffsetCurve)

class Adaptor2d_Line2d(Adaptor2d_Curve2d):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        P: gp_Pnt2d
        D: gp_Dir2d
        UFirst: float
        ULast: float

        Returns
        -------
        None

        """
        _Adaptor2d.Adaptor2d_Line2d_swiginit(self, _Adaptor2d.new_Adaptor2d_Line2d(*args))

    def Load(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        L: gp_Lin2d

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        L: gp_Lin2d
        UFirst: float
        ULast: float

        Returns
        -------
        None

        """
        return _Adaptor2d.Adaptor2d_Line2d_Load(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _Adaptor2d.delete_Adaptor2d_Line2d

# Register Adaptor2d_Line2d in _Adaptor2d:
_Adaptor2d.Adaptor2d_Line2d_swigregister(Adaptor2d_Line2d)

class Adaptor2d_OffsetCurve(Adaptor2d_Curve2d):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        The offset is set to 0.

        Returns
        -------
        None
        The curve is loaded. the offset is set to 0.

        Parameters
        ----------
        C: Adaptor2d_HCurve2d

        Returns
        -------
        None
        Creates an offsetcurve curve. the offset is set to offset.

        Parameters
        ----------
        C: Adaptor2d_HCurve2d
        Offset: float

        Returns
        -------
        None
        Create an offset curve. wfirst,wlast define the bounds of the offset curve.

        Parameters
        ----------
        C: Adaptor2d_HCurve2d
        Offset: float
        WFirst: float
        WLast: float

        Returns
        -------
        None

        """
        _Adaptor2d.Adaptor2d_OffsetCurve_swiginit(self, _Adaptor2d.new_Adaptor2d_OffsetCurve(*args))

    def Curve(self, *args) -> "opencascade::handle< Adaptor2d_HCurve2d > const &":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<Adaptor2d_HCurve2d>

        """
        return _Adaptor2d.Adaptor2d_OffsetCurve_Curve(self, *args)

    def Load(self, *args) -> "void":
        r"""
        Changes the curve. the offset is reset to 0.

        Parameters
        ----------
        S: Adaptor2d_HCurve2d

        Returns
        -------
        None
        Changes the offset on the current curve.

        Parameters
        ----------
        Offset: float

        Returns
        -------
        None
        Changes the offset curve on the current curve.

        Parameters
        ----------
        Offset: float
        WFirst: float
        WLast: float

        Returns
        -------
        None

        """
        return _Adaptor2d.Adaptor2d_OffsetCurve_Load(self, *args)

    def Offset(self, *args) -> "Standard_Real":
        r"""
        No available documentation.

        Returns
        -------
        float

        """
        return _Adaptor2d.Adaptor2d_OffsetCurve_Offset(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _Adaptor2d.delete_Adaptor2d_OffsetCurve

# Register Adaptor2d_OffsetCurve in _Adaptor2d:
_Adaptor2d.Adaptor2d_OffsetCurve_swigregister(Adaptor2d_OffsetCurve)





